@@ -3,13 +3,16 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 # shortcuts
+#  os and distros
 use constant os_freebsd  => (os => 'freebsd');
 use constant os_windows  => (os => 'MSWin32');
 use constant os_darwin   => (os => 'darwin'); # really means installer=homebrew
 use constant like_debian => (linuxdistro => '~debian');
+#  package shortcuts
+use constant freebsd_jpeg => 'jpeg | jpeg-turbo';
 
 sub mapping {
     (
@@ -115,7 +118,10 @@ sub mapping {
      ],
 
      [cpanmod => 'Alien::uPB',
-      [package => 'unzip']],
+      # freebsd and darwin have /usr/bin/unzip in the base system
+      [os => 'linux',
+       [package => 'unzip']],
+     ],
 
      [cpanmod => 'Alien::wxWidgets',
       [os_freebsd,
@@ -335,6 +341,10 @@ sub mapping {
       [os_windows,
        [package => 'openssl.light']]], # XXX create openssl.dev
 
+     [cpanmod => 'Crypt::OpenSSL::X509',
+      [os_darwin,
+       [package => 'openssl']]],
+
      [cpanmod => 'Crypt::OTR',
       [os_freebsd,
        [package => 'libotr']],
@@ -415,7 +425,8 @@ sub mapping {
        [package => 'firebird-dev']]],
 
      [cpanmod => 'DBD::mysql',
-      # XXX freebad?
+      [os_freebsd,
+       [package => 'mysql-connector-c | mysql57-client | mysql56-client | mysql55-client | mariadb101-client | mariadb100-client | mariadb55-client | percona56-client | percona55-client']],
       [like_debian,
        [package => 'libmysqlclient-dev']],
       [os_darwin,
@@ -811,7 +822,7 @@ sub mapping {
 
      [cpanmod => 'Image::Scale',
       [os_freebsd,
-       [package => [qw(png jpeg)]]],
+       [package => ['png', freebsd_jpeg]]],
       [like_debian,
        [package => [qw(libjpeg-dev libpng12-dev)]]]],
 
@@ -822,7 +833,7 @@ sub mapping {
 
      [cpanmod => 'Imager',
       [os_freebsd,
-       [package => [qw(freetype2 giflib png tiff), 'jpeg | jpeg-turbo']]], # in former days giflib-nox11 had to be specified
+       [package => [qw(freetype2 giflib png tiff), freebsd_jpeg]]], # in former days giflib-nox11 had to be specified
       [like_debian,
        [linuxdistrocodename => 'wheezy',
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
@@ -979,7 +990,7 @@ sub mapping {
       [like_debian,
        [package => 'libopendkim-dev']]],
 
-     [cpanmod => 'Math::FFTW',
+     [cpanmod => ['Math::FFTW', 'PDL::FFTW3'],
       [os_freebsd,
        [package => 'fftw3']],
       [like_debian,
@@ -1454,7 +1465,7 @@ sub mapping {
       # freetype2 and libXft are optional, but highly recommended as it provides nicer fonts
       # jpeg and png is bundled in Tk, but usually the Tk version is older
       [os_freebsd,
-       [package => qw(freetype2 libXft libX11 jpeg png)]],
+       [package => qw(freetype2 libXft libX11 png), freebsd_jpeg]],
       [like_debian,
        [package => [qw(libx11-dev libfreetype6-dev libxft-dev libpng-dev libz-dev libjpeg-dev)]]],
       [linuxdistro => '~fedora',
